@@ -18,6 +18,7 @@
 # Changelog:
 # APS 01/29/2004: Changed run_nmap_scan to use parsescan().
 #		  $nmap_exe is set to default 'nmap' if find_exe returns empty
+# APS 02/03/2004: Added ability to read IPs from a file
 #
 #
 #
@@ -29,8 +30,8 @@ use File::Spec;
 use Pod::Usage;
 use Getopt::Long;
 use vars qw(%G);
-use constant CMD1 => '-sV';
-use constant FAST_CMD => '-sV -F';
+use constant CMD1 => '-sV --randomize_hosts';
+use constant FAST_CMD => '-sV -F --randomize_hosts';
 Getopt::Long::Configure('bundling');
 
 GetOptions(
@@ -38,14 +39,16 @@ GetOptions(
 		'F'		=> \$G{fast},
 		'v+'		=> \$G{verbose},
 		'i=s'		=> \$G{usefile},
-		'o=s'		=> \$G{output}
-) or (pod2usage(-exitstatus => 0, -verbose => 1));
+		'o=s'		=> \$G{output},
+		'L=s'		=> \$G{ipfile},
+) or (pod2usage(-exitstatus => 0, -verbose => 2));
 
-if($G{helpme} || ($G{usefile} eq '' && scalar @ARGV == 0))
-	{pod2usage(-exitstatus => 0, -verbose => 1);}
+if($G{helpme} || (!$G{usefile} && scalar @ARGV == 0 && !$G{ipfile}))
+	{pod2usage(-exitstatus => 0, -verbose => 2);}
 
 print STDERR "FastScan enabled\n" if($G{verbose} > 0 && $G{fast});
-print "\nPort Info\t".(scalar localtime)."\n",('-'x50),"\n\n";
+print "\nport_info.pl - ( http://npx.sourceforge.net )\n",
+	('-'x50),"\n\n";
 
 
 my $OUT = $G{output} || OUT_FILE;
@@ -130,6 +133,9 @@ close OUT;
 print "\n\nOutput file generated: $OUT\n";
 exit;
 
+################################################################################
+##				Utility Functions			      ##
+################################################################################
 
 sub find_exe {
 
@@ -162,8 +168,18 @@ sub find_exe {
 
 sub run_nmap_scan {
 my @ips = @_;
-my $NMAP;
-	my $cmd;
+my($NMAP,$cmd);
+
+	if($G{ipfile} && -e $G{ipfile})
+		{push @ips ,read_ips_from_file($G{ipfile});
+		if($G{verbose} > 0){
+		print STDERR "\nIP file contains:\n";
+		for(@ips){print STDERR "\t$_\n";}
+		print "\n";}
+		}
+	elsif($G{ipfile} && !-e $G{ipfile})
+		{warn "WARNING: IP file $G{ipfile} does not exist!\n";}
+
 	if($G{fast}){
 
 	$cmd = join ' ', (FAST_CMD, @ips);
@@ -183,6 +199,24 @@ my $NMAP;
 return $p;
 }
 
+sub read_ips_from_file {
+my $filename = shift;
+my @ips;
+open FILE, "$filename" || die "ERROR: Could not open $filename! \nERROR: $!";
+for(<FILE>){
+chomp; # no newline
+s/#.*//; # no comments
+s/^\s+//; # no leading white
+s/\s+$//; # no trailing white
+next unless length; # anything left?
+push @ips , $_; #it might be a host name too, so don't expect only numbers
+	}
+close FILE;
+
+return @ips;
+
+}
+
 __END__
 
 =pod
@@ -201,7 +235,8 @@ This script uses the nmap security scanner with the Nmap::Parser::XML module
 in order to run a quick PING sweep against specific hosts. It takes in a nmap
 xml file and outputs onto STDOUT and a file the all the ports that were scanned
 and found by nmap, their different states and services -- all in a comma
-delimited output
+delimited output. B<This script uses the -sV output to get version information
+of the services running on a machine. This requires nmap version 3.49+>
 
 =head1 OPTIONS
 
@@ -223,6 +258,11 @@ Runs a fast (-F) nmap scan against the host.
 
 Shows this help information.
 
+=item B<-L ips.txt>
+
+Reads IP addresses from filename.txt to run a scan against. The IP addresses
+should be in the target specification format explained below.
+
 =item B<-o outputfile.csv>
 
 Changes the output filename of the comma delimited file that is produced by
